@@ -1,4 +1,5 @@
-package DBIx::Class::CDBICompat::LiveObjectIndex;
+package # hide from PAUSE 
+    DBIx::Class::CDBICompat::LiveObjectIndex;
 
 use strict;
 use warnings;
@@ -51,7 +52,7 @@ sub insert {
   return $self;
 }
 
-sub _row_to_object {
+sub inflate_result {
   my ($class, @rest) = @_;
   my $new = $class->next::method(@rest);
   if (my $key = $new->ID) {
