@@ -7,12 +7,12 @@ no warnings 'qw';
 use base qw/DBIx::Class/;
 
 __PACKAGE__->load_components(qw/
+  Serialize::Storable
   InflateColumn
   Relationship
   PK
   Row
   ResultSourceProxy::Table
-  Exception
   AccessorGroup/);
 
 1;
@@ -45,8 +45,6 @@ The core modules currently are:
 
 =item L<DBIx::Class::ResultSourceProxy::Table>
 
-=item L<DBIx::Class::Exception>
-
 =item L<DBIx::Class::AccessorGroup>
 
 =back
