@@ -14,7 +14,7 @@ __PACKAGE__->load_components(qw/ResultSetProxy/);
 sub storage { shift->schema_instance(@_)->storage; }
 
 sub resultset_instance {
-  my $class = shift;
+  my $class = ref $_[0] || $_[0];
   my $source = $class->result_source_instance;
   if ($source->result_class ne $class) {
     $source = $source->new($source);
@@ -56,7 +56,9 @@ will be focused on Schema-based DBIx::Class setups.
 
 Sets or gets the storage backend. Defaults to L<DBIx::Class::Storage::DBI>.
 
-=head2 class_resolver ****DEPRECATED****
+=head2 class_resolver
+
+****DEPRECATED****
 
 Sets or gets the class to use for resolving a class. Defaults to 
 L<DBIx::Class::ClassResolver::Passthrough>, which returns whatever you give
@@ -65,7 +67,7 @@ it. See resolve_class below.
 =cut
 
 __PACKAGE__->mk_classdata('class_resolver' =>
-                            'DBIx::Class::ClassResolver::PassThrough');
+                          'DBIx::Class::ClassResolver::PassThrough');
 
 =head2 connection
 
@@ -104,7 +106,7 @@ Begins a transaction (does nothing if AutoCommit is off).
 
 =cut
 
-sub txn_begin { $_[0]->storage->txn_begin }
+sub txn_begin { shift->schema_instance->txn_begin(@_); }
 
 =head2 txn_commit
 
@@ -112,7 +114,7 @@ Commits the current transaction.
 
 =cut
 
-sub txn_commit { $_[0]->storage->txn_commit }
+sub txn_commit { shift->schema_instance->txn_commit(@_); }
 
 =head2 txn_rollback
 
@@ -120,7 +122,17 @@ Rolls back the current transaction.
 
 =cut
 
-sub txn_rollback { $_[0]->storage->txn_rollback }
+sub txn_rollback { shift->schema_instance->txn_rollback(@_); }
+
+=head2 txn_do
+
+Executes a block of code transactionally. If this code reference
+throws an exception, the transaction is rolled back and the exception
+is rethrown. See txn_do in L<DBIx::Class::Schema> for more details.
+
+=cut
+
+sub txn_do { shift->schema_instance->txn_do(@_); }
 
 {
   my $warn;
