@@ -6,17 +6,13 @@ use warnings;
 use base qw/DBIx::Class/;
 
 __PACKAGE__->load_own_components(qw/
-  HasMany
-  HasOne
-  BelongsTo
+  Helpers
   Accessor
   CascadeActions
   ProxyMethods
   Base
 /);
 
-__PACKAGE__->mk_classdata('_relationships', { } );
-
 =head1 NAME 
 
 DBIx::Class::Relationship - Inter-table relationships
@@ -100,6 +96,16 @@ except the implication is that the other object is always present. The only diff
 between C<has_one> and C<might_have> is that C<has_one> uses an (ordinary) inner join,
 whereas C<might_have> uses a left join.
 
+
+=head2 many_to_many
+
+  __PACKAGE__->many_to_many( 'accessorname' => 'a_to_b', 'table_b' );
+  my @f_objs = $obj_a->accessorname;
+
+Creates an accessor bridging two relationships; not strictly a relationship
+in its own right, although the accessor will return a resultset or collection
+of objects just as a has_many would.
+
 =cut
 
 1;
