@@ -210,8 +210,8 @@ use base qw/DBIx::Class/;
 __PACKAGE__->load_components(qw/AccessorGroup/);
 
 __PACKAGE__->mk_group_accessors('simple' =>
-  qw/connect_info _dbh _sql_maker _connection_pid debug debugfh cursor
-     on_connect_do transaction_depth/);
+  qw/connect_info _dbh _sql_maker _conn_pid _conn_tid debug debugfh
+     cursor on_connect_do transaction_depth/);
 
 sub new {
   my $new = bless({}, ref $_[0] || $_[0]);
@@ -290,8 +290,20 @@ sub disconnect {
 sub connected {
   my ($self) = @_;
 
-  my $dbh;
-  (($dbh = $self->_dbh) && $dbh->FETCH('Active') && $dbh->ping)
+  if(my $dbh = $self->_dbh) {
+      if(defined $self->_conn_tid && $self->_conn_tid != threads->tid) {
+          $self->_sql_maker(undef);
+          return $self->_dbh(undef);
+      }
+      elsif($self->_conn_pid != $$) {
+          $self->_dbh->{InactiveDestroy} = 1;
+          $self->_sql_maker(undef);
+          return $self->_dbh(undef)
+      }
+      return ($dbh->FETCH('Active') && $dbh->ping);
+  }
+
+  return 0;
 }
 
 sub ensure_connected {
@@ -305,10 +317,6 @@ sub ensure_connected {
 sub dbh {
   my ($self) = @_;
 
-  if($self->_connection_pid && $self->_connection_pid != $$) {
-      $self->_dbh->{InactiveDestroy} = 1;
-      $self->_dbh(undef)
-  }
   $self->ensure_connected;
   return $self->_dbh;
 }
@@ -335,12 +343,16 @@ sub _populate_dbh {
     $self->_dbh->do($sql_statement);
   }
 
-  $self->_connection_pid($$);
+  $self->_conn_pid($$);
+  $self->_conn_tid(threads->tid) if $INC{'threads.pm'};
 }
 
 sub _connect {
   my ($self, @info) = @_;
 
+  $self->throw_exception("You failed to provide any connection info")
+      if !@info;
+
   my ($old_connect_via, $dbh);
 
   if ($INC{'Apache/DBI.pm'} && $ENV{MOD_PERL}) {
@@ -412,7 +424,7 @@ sub txn_rollback {
     else {
       --$self->{transaction_depth} == 0 ?
         $self->dbh->rollback :
-	die DBIx::Class::Storage::NESTED_ROLLBACK_EXCEPTION->new;
+        die DBIx::Class::Storage::NESTED_ROLLBACK_EXCEPTION->new;
     }
   };
 
@@ -511,25 +523,48 @@ Returns database type info for a given table columns.
 
 sub columns_info_for {
     my ($self, $table) = @_;
-    my %result;
-    if ( $self->dbh->can( 'column_info' ) ){
-        my $sth = $self->dbh->column_info( undef, undef, $table, '%' );
-        $sth->execute();
-        while ( my $info = $sth->fetchrow_hashref() ){
-            my %column_info;
-            $column_info{data_type} = $info->{TYPE_NAME};
-            $column_info{size} = $info->{COLUMN_SIZE};
-            $column_info{is_nullable} = $info->{NULLABLE};
-            $result{$info->{COLUMN_NAME}} = \%column_info;
-        }
-    } else {
-        my $sth = $self->dbh->prepare("SELECT * FROM $table WHERE 1=0");
-        $sth->execute;
-        my @columns = @{$sth->{NAME}};
-        for my $i ( 0 .. $#columns ){
-            $result{$columns[$i]}{data_type} = $sth->{TYPE}->[$i];
-        }
+
+    if ($self->dbh->can('column_info')) {
+        my %result;
+        my $old_raise_err = $self->dbh->{RaiseError};
+        my $old_print_err = $self->dbh->{PrintError};
+        $self->dbh->{RaiseError} = 1;
+        $self->dbh->{PrintError} = 0;
+        eval {
+            my $sth = $self->dbh->column_info( undef, undef, $table, '%' );
+            $sth->execute();
+            while ( my $info = $sth->fetchrow_hashref() ){
+                my %column_info;
+                $column_info{data_type} = $info->{TYPE_NAME};
+                $column_info{size} = $info->{COLUMN_SIZE};
+                $column_info{is_nullable} = $info->{NULLABLE} ? 1 : 0;
+                $column_info{default_value} = $info->{COLUMN_DEF};
+                $result{$info->{COLUMN_NAME}} = \%column_info;
+            }
+        };
+        $self->dbh->{RaiseError} = $old_raise_err;
+        $self->dbh->{PrintError} = $old_print_err;
+        return \%result if !$@;
     }
+
+    my %result;
+    my $sth = $self->dbh->prepare("SELECT * FROM $table WHERE 1=0");
+    $sth->execute;
+    my @columns = @{$sth->{NAME_lc}};
+    for my $i ( 0 .. $#columns ){
+        my %column_info;
+        my $type_num = $sth->{TYPE}->[$i];
+        my $type_name;
+        if(defined $type_num && $self->dbh->can('type_info')) {
+            my $type_info = $self->dbh->type_info($type_num);
+            $type_name = $type_info->{TYPE_NAME} if $type_info;
+        }
+        $column_info{data_type} = $type_name ? $type_name : $type_num;
+        $column_info{size} = $sth->{PRECISION}->[$i];
+        $column_info{is_nullable} = $sth->{NULLABLE}->[$i] ? 1 : 0;
+        $result{$columns[$i]} = \%column_info;
+    }
+
     return \%result;
 }
 
@@ -560,7 +595,7 @@ sub deploy {
   my ($self, $schema, $type, $sqltargs) = @_;
   foreach(split(";\n", $self->deployment_statements($schema, $type, $sqltargs))) {
       $self->debugfh->print("$_\n") if $self->debug;
-	  $self->dbh->do($_) or warn "SQL was:\n $_";
+          $self->dbh->do($_) or warn "SQL was:\n $_";
   } 
 }
 
