@@ -1,8 +1,9 @@
-package DBICTest::Plain;
+package # hide from PAUSE 
+    DBICTest::Plain;
 
 use strict;
 use warnings;
-use base qw/Catalyst::Model::DBIC::Plain/;
+use base qw/DBIx::Class::Schema/;
 use DBI;
 
 my $db_file = "t/var/Plain.db";
@@ -13,7 +14,7 @@ mkdir("t/var") unless -d "t/var";
 
 my $dsn = "dbi:SQLite:${db_file}";
 
-__PACKAGE__->load_classes;
+__PACKAGE__->load_classes("Test");
 my $schema = __PACKAGE__->compose_connection(__PACKAGE__, $dsn);
 
 my $dbh = DBI->connect($dsn);
