@@ -9,7 +9,9 @@ __PACKAGE__->table('treelike');
 __PACKAGE__->add_columns(
   'id' => { data_type => 'integer', is_auto_increment => 1 },
   'parent' => { data_type => 'integer' },
-  'name' => { data_type => 'varchar' },
+  'name' => { data_type => 'varchar',
+    size      => 100,
+ },
 );
 __PACKAGE__->set_primary_key(qw/id/);
 __PACKAGE__->belongs_to('parent', 'TreeLike',
