@@ -1,6 +1,6 @@
 -- 
 -- Created by SQL::Translator::Producer::SQLite
--- Created on Mon Feb  6 01:07:16 2006
+-- Created on Fri Feb 24 15:13:57 2006
 -- 
 BEGIN TRANSACTION;
 
@@ -77,14 +77,6 @@ CREATE TABLE artist_undirected_map (
   PRIMARY KEY (id1, id2)
 );
 
---
--- Table: producer
---
-CREATE TABLE producer (
-  producerid INTEGER PRIMARY KEY NOT NULL,
-  name varchar NOT NULL
-);
-
 --
 -- Table: onekey
 --
@@ -104,6 +96,14 @@ CREATE TABLE track (
   title varchar NOT NULL
 );
 
+--
+-- Table: producer
+--
+CREATE TABLE producer (
+  producerid INTEGER PRIMARY KEY NOT NULL,
+  name varchar NOT NULL
+);
+
 --
 -- Table: treelike
 --
@@ -117,10 +117,9 @@ CREATE TABLE treelike (
 -- Table: tags
 --
 CREATE TABLE tags (
-  tagid varchar NOT NULL,
+  tagid INTEGER PRIMARY KEY NOT NULL,
   cd integer NOT NULL,
-  tag varchar NOT NULL,
-  PRIMARY KEY (tagid)
+  tag varchar NOT NULL
 );
 
 --
@@ -131,4 +130,12 @@ CREATE TABLE self_ref (
   name varchar NOT NULL
 );
 
+--
+-- Table: serialized
+--
+CREATE TABLE serialized (
+    id INTEGER PRIMARY KEY NOT NULL,
+    serialized text NOT NULL
+);
+
 COMMIT;
